Module `ligo.skymap.distance`
==============================
.. module:: ligo.skymap.distance

Functions for working with distance posteriors.

.. autofunction:: conditional_pdf
.. autofunction:: conditional_cdf
.. autofunction:: conditional_ppf
.. autofunction:: moments_to_parameters
.. autofunction:: parameters_to_moments
.. autofunction:: volume_render
.. autofunction:: marginal_pdf
.. autofunction:: marginal_cdf
.. autofunction:: marginal_ppf
.. autofunction:: ud_grade
.. autofunction:: conditional_kde
.. autofunction:: cartesian_kde_to_moments
.. autofunction:: principal_axes
.. autofunction:: parameters_to_moments
